@@ -94,7 +94,6 @@ class Service(PackageConfiguration):  # pylint: disable=too-many-instance-attrib
         "fingerprint_ignore_patterns",
         "build_entrypoint",
         "agent",
-        "network",
         "number_of_agents",
         "_aea_version",
         "_aea_version_specifiers",
@@ -114,7 +113,6 @@ class Service(PackageConfiguration):  # pylint: disable=too-many-instance-attrib
         fingerprint_ignore_patterns: Optional[Sequence[str]] = None,
         description: str = "",
         number_of_agents: int = 4,
-        network: Optional[str] = None,
         build_entrypoint: Optional[str] = None,
         overrides: Optional[List] = None,
     ) -> None:
@@ -134,7 +132,6 @@ class Service(PackageConfiguration):  # pylint: disable=too-many-instance-attrib
         self.agent = PublicId.from_str(str(agent))
         self.description = description
         self.number_of_agents = number_of_agents
-        self.network = network
 
         self._overrides = [] if overrides is None else overrides
 
@@ -170,7 +167,6 @@ class Service(PackageConfiguration):  # pylint: disable=too-many-instance-attrib
                 "aea_version": self.aea_version,
                 "description": self.description,
                 "number_of_agents": self.number_of_agents,
-                "network": self.network,
                 "overrides": self.overrides,
                 "fingerprint": self.fingerprint,
                 "fingerprint_ignore_patterns": self.fingerprint_ignore_patterns,
@@ -193,7 +189,6 @@ class Service(PackageConfiguration):  # pylint: disable=too-many-instance-attrib
             aea_version=cast(str, obj.get("aea_version")),
             description=cast(str, obj.get("description")),
             number_of_agents=cast(int, obj.get("number_of_agents")),
-            network=cast(str, obj.get("network")),
             overrides=cast(List, obj.get("overrides", [])),
             fingerprint=cast(Dict[str, str], obj.get("fingerprint", [])),
             fingerprint_ignore_patterns=cast(
@@ -358,13 +353,11 @@ class Service(PackageConfiguration):  # pylint: disable=too-many-instance-attrib
                 raise ValueError(
                     "All keys of list like override should be of type int."
                 )
-            nums = set(field_override.keys())
-
-            if len(nums) != self.number_of_agents:
-                raise ValueError("Not enough items in override")
-
-            if nums != set(range(0, self.number_of_agents)):
-                raise ValueError("Overrides incorrectly indexed")
+            override_index = set(field_override.keys())
+            if self.number_of_agents > len(override_index):
+                raise ValueError(
+                    f"Not enough items in override, Number of agents = {self.number_of_agents}; Number of overrides provided = {len(override_index)}"
+                )
 
             n_fields = len(field_override)
             for override in field_override[component_index % n_fields]:
