@@ -56,6 +56,9 @@ from packages.open_aea.protocols.signing.custom_types import (
 from packages.valory.connections.http_client.connection import (
     PUBLIC_ID as HTTP_CLIENT_PUBLIC_ID,
 )
+from packages.valory.contracts.service_registry.contract import (  # noqa: F401  # pylint: disable=unused-import
+    ServiceRegistryContract,
+)
 from packages.valory.protocols.contract_api import ContractApiMessage
 from packages.valory.protocols.http import HttpMessage
 from packages.valory.protocols.ledger_api import LedgerApiMessage
@@ -93,13 +96,16 @@ from packages.valory.skills.abstract_round_abci.models import (
 )
 
 
+# TODO: port registration code from registration_abci to here
+
+
 MIN_HEIGHT_OFFSET = 10
 HEIGHT_OFFSET_MULTIPLIER = 1
 NON_200_RETURN_CODE_DURING_RESET_THRESHOLD = 3
 GENESIS_TIME_FMT = "%Y-%m-%dT%H:%M:%S.%fZ"
 ROOT_HASH = "726F6F743A3"
 RESET_HASH = "72657365743A3"
-APP_HASH_RE = fr"{ROOT_HASH}\d+{RESET_HASH}(\d+)"
+APP_HASH_RE = rf"{ROOT_HASH}\d+{RESET_HASH}(\d+)"
 INITIAL_APP_HASH = ""
 
 
