@@ -32,11 +32,11 @@ from aea.helpers.base import IPFS_HASH_REGEX, SIMPLE_ID_REGEX
 
 CLI_REGEX = r"(?P<cli>aea|autonomy)"
 CMD_REGEX = r"(?P<cmd>.*)"
-VENDOR_REGEX = fr"(?P<vendor>{SIMPLE_ID_REGEX})"
-PACKAGE_REGEX = fr"(?P<package>{SIMPLE_ID_REGEX})"
+VENDOR_REGEX = rf"(?P<vendor>{SIMPLE_ID_REGEX})"
+PACKAGE_REGEX = rf"(?P<package>{SIMPLE_ID_REGEX})"
 VERSION_REGEX = r"(?P<version>\d+\.\d+\.\d+)"
 
-AEA_COMMAND_REGEX = fr"(?P<full_cmd>{CLI_REGEX} {CMD_REGEX} (?:{VENDOR_REGEX}\/{PACKAGE_REGEX}:{VERSION_REGEX}?:?)?(?P<hash>{IPFS_HASH_REGEX}))"
+AEA_COMMAND_REGEX = rf"(?P<full_cmd>{CLI_REGEX} {CMD_REGEX} (?:{VENDOR_REGEX}\/{PACKAGE_REGEX}:{VERSION_REGEX}?:?)?(?P<hash>{IPFS_HASH_REGEX}))"
 
 ROOT_DIR = Path(__file__).parent.parent
 
@@ -97,7 +97,7 @@ class Package:  # pylint: disable=too-few-public-methods
                     self.last_version = resource["version"]
                     break
 
-    def get_command(self, cmd, include_version=True) -> str:
+    def get_command(self, cmd: str, include_version=True) -> str:
         """Get the corresponding command"""
         version = (
             ":" + self.last_version if include_version and self.last_version else ""
@@ -165,17 +165,38 @@ class PackageHashManager:
                 return None
 
             # Complete command, succesfully retrieved
-            package_type = None
-            if "deployment" in d["cmd"]:
-                package_type = "service"
-            if d["cmd"] == "fetch":
-                package_type = "agent"
-            if d["cmd"].startswith("add"):
-                package_type = d["cmd"].split(" ")[-1]  # i.e.: aea add connection
-            if not package_type:
-                raise ValueError(
-                    f"Docs [{md_file}]: could not infer the package type for line '{package_line}'"
-                )
+
+            # Guess the package type (agent, service, contract...). First try to find the package in the package_tree
+            potential_package_types = []
+            for package_type, packages in self.package_tree[d["vendor"]].items():
+                if d["package"] in packages.keys():
+                    potential_package_types.append(package_type)
+
+            # If only 1 match has been found we can be sure about the package type
+            if len(potential_package_types) == 1:
+                package_type = potential_package_types[0]
+            else:
+                # Try to guess the package type from the command
+                package_type = None
+
+                # Fetch option is only available for agents and services
+                if d["cmd"] == "fetch":
+                    package_type = (
+                        "service" if "--service" in d["full_cmd"] else "agent"
+                    )
+
+                # Deployments are always services
+                if "deployment" in d["cmd"]:
+                    package_type = "service"
+
+                # Add commands always specify the package type
+                if d["cmd"].startswith("add"):
+                    package_type = d["cmd"].split(" ")[-1]  # i.e.: aea add connection
+
+                if not package_type:
+                    raise ValueError(
+                        f"Docs [{md_file}]: could not infer the package type for line '{package_line}'\nPlease update the hash manually."
+                    )
 
             return self.package_tree[d["vendor"]][package_type][d["package"]].hash
 
