@@ -20,7 +20,10 @@
 """End2end tests for the valory/hello_world skill."""
 import pytest
 
-from tests.test_agents.base import BaseTestEnd2EndExecution, RoundChecks
+from autonomy.test_tools.base_test_classes.agents import (
+    BaseTestEnd2EndExecution,
+    RoundChecks,
+)
 
 
 HAPPY_PATH = (
