@@ -22,7 +22,10 @@
 import pytest
 from aea.configurations.data_types import PublicId
 
-from tests.test_agents.base import BaseTestEnd2EndExecution, RoundChecks
+from autonomy.test_tools.base_test_classes.agents import (
+    BaseTestEnd2EndExecution,
+    RoundChecks,
+)
 
 
 HAPPY_PATH = (
