@@ -26,6 +26,7 @@ from typing import Tuple
 from unittest import mock
 
 import yaml
+from aea.configurations.constants import PACKAGES
 
 from autonomy.constants import (
     DEFAULT_BUILD_FOLDER,
@@ -33,17 +34,18 @@ from autonomy.constants import (
     TENDERMINT_IMAGE_NAME,
 )
 from autonomy.deploy.constants import (
+    DEBUG,
     DEPLOYMENT_AGENT_KEY_DIRECTORY_SCHEMA,
     DEPLOYMENT_KEY_DIRECTORY,
     KUBERNETES_AGENT_KEY_NAME,
 )
-
-from tests.conftest import (
+from autonomy.test_tools.configurations import (
     ETHEREUM_ENCRYPTED_KEYS,
     ETHEREUM_ENCRYPTION_PASSWORD,
-    ROOT_DIR,
 )
-from tests.helpers.docker.base import skip_docker_tests
+from autonomy.test_tools.docker.base import skip_docker_tests
+
+from tests.conftest import ROOT_DIR
 from tests.test_autonomy.test_cli.base import BaseCliTest
 
 
@@ -51,7 +53,7 @@ from tests.test_autonomy.test_cli.base import BaseCliTest
 class TestBuildDeployment(BaseCliTest):
     """Test `autonomy deply build deployment` command."""
 
-    cli_options: Tuple[str, ...] = ("deploy", "build", "deployment")
+    cli_options: Tuple[str, ...] = ("deploy", "build")
     service_id: str = "valory/oracle_hardhat"
 
     keys_file: Path
@@ -64,12 +66,16 @@ class TestBuildDeployment(BaseCliTest):
 
         cls.keys_file = cls.t / "keys.json"
 
-        shutil.copytree(ROOT_DIR / "packages", cls.t / "packages")
+        shutil.copytree(ROOT_DIR / PACKAGES, cls.t / PACKAGES)
         shutil.copy(
             ROOT_DIR / "deployments" / "keys" / "hardhat_keys.json", cls.keys_file
         )
 
-        os.chdir(cls.t)
+        shutil.copytree(
+            cls.t / PACKAGES / "valory" / "services" / "hello_world",
+            cls.t / "hello_world",
+        )
+        os.chdir(cls.t / "hello_world")
 
     def test_docker_compose_build(
         self,
@@ -79,12 +85,9 @@ class TestBuildDeployment(BaseCliTest):
         with mock.patch("os.chown"):
             result = self.run_cli(
                 (
-                    self.service_id,
                     str(self.keys_file),
-                    "--packages-dir",
-                    str(self.t / "packages"),
                     "--o",
-                    str(self.t),
+                    str(self.t / DEFAULT_BUILD_FOLDER),
                     "--force",
                     "--local",
                 )
@@ -121,6 +124,52 @@ class TestBuildDeployment(BaseCliTest):
             ]
         )
 
+    def test_docker_compose_build_log_level(
+        self,
+    ) -> None:
+        """Run tests."""
+
+        with mock.patch("os.chown"):
+            result = self.run_cli(
+                (
+                    str(self.keys_file),
+                    "--o",
+                    str(self.t / DEFAULT_BUILD_FOLDER),
+                    "--force",
+                    "--local",
+                    "--log-level",
+                    DEBUG,
+                )
+            )
+
+        build_dir = self.t / "abci_build"
+
+        assert result.exit_code == 0, f"{result.stdout_bytes}\n{result.stderr_bytes}"
+        assert build_dir.exists()
+
+        build_tree = list(map(lambda x: x.name, build_dir.iterdir()))
+        assert any(
+            [
+                child in build_tree
+                for child in ["persistent_storage", "nodes", "docker-compose.yaml"]
+            ]
+        )
+
+        docker_compose_file = build_dir / "docker-compose.yaml"
+        with open(docker_compose_file, "r", encoding="utf-8") as fp:
+            docker_compose = yaml.safe_load(fp)
+
+        assert any(
+            [key in docker_compose for key in ["version", "services", "networks"]]
+        )
+
+        assert (
+            f"LOG_LEVEL={DEBUG}" in docker_compose["services"]["abci0"]["environment"]
+        )
+        assert (
+            f"LOG_LEVEL={DEBUG}" in docker_compose["services"]["node0"]["environment"]
+        )
+
     def test_docker_compose_build_dev(
         self,
     ) -> None:
@@ -129,12 +178,9 @@ class TestBuildDeployment(BaseCliTest):
         with mock.patch("os.chown"):
             result = self.run_cli(
                 (
-                    self.service_id,
                     str(self.keys_file),
-                    "--packages-dir",
-                    str(self.t / "packages"),
                     "--o",
-                    str(self.t),
+                    str(self.t / DEFAULT_BUILD_FOLDER),
                     "--force",
                     "--dev",
                     "--local",
@@ -180,12 +226,9 @@ class TestBuildDeployment(BaseCliTest):
         with mock.patch("os.chown"):
             result = self.run_cli(
                 (
-                    self.service_id,
                     str(self.keys_file),
-                    "--packages-dir",
-                    str(self.t / "packages"),
                     "--o",
-                    str(self.t),
+                    str(self.t / DEFAULT_BUILD_FOLDER),
                     "--kubernetes",
                     "--force",
                     "--local",
@@ -202,6 +245,42 @@ class TestBuildDeployment(BaseCliTest):
             [child in build_tree for child in ["persistent_storage", "build.yaml"]]
         )
 
+    def test_kubernetes_build_log_level(
+        self,
+    ) -> None:
+        """Run tests."""
+
+        with mock.patch("os.chown"):
+            result = self.run_cli(
+                (
+                    str(self.keys_file),
+                    "--o",
+                    str(self.t / DEFAULT_BUILD_FOLDER),
+                    "--kubernetes",
+                    "--force",
+                    "--local",
+                    "--log-level",
+                    DEBUG,
+                )
+            )
+
+        build_dir = self.t / "abci_build"
+
+        assert result.exit_code == 0, f"{result.stdout_bytes}\n{result.stderr_bytes}"
+        assert build_dir.exists()
+
+        build_tree = list(map(lambda x: x.name, build_dir.iterdir()))
+        assert any(
+            [child in build_tree for child in ["persistent_storage", "build.yaml"]]
+        )
+
+        with open(build_dir / "build.yaml", "r") as fp:
+            build_config = list(yaml.safe_load_all(fp))
+
+        assert {"name": "LOG_LEVEL", "value": DEBUG} in build_config[1]["spec"][
+            "template"
+        ]["spec"]["containers"][0]["env"]
+
     def test_kubernetes_build_dev(
         self,
     ) -> None:
@@ -210,12 +289,9 @@ class TestBuildDeployment(BaseCliTest):
         with mock.patch("os.chown"):
             result = self.run_cli(
                 (
-                    self.service_id,
                     str(self.keys_file),
-                    "--packages-dir",
-                    str(self.t / "packages"),
                     "--o",
-                    str(self.t),
+                    str(self.t / DEFAULT_BUILD_FOLDER),
                     "--kubernetes",
                     "--force",
                     "--dev",
@@ -242,12 +318,9 @@ class TestBuildDeployment(BaseCliTest):
         with mock.patch("os.chown"):
             result = self.run_cli(
                 (
-                    self.service_id,
                     str(self.keys_file),
-                    "--packages-dir",
-                    str(self.t / "packages"),
                     "--o",
-                    str(self.t),
+                    str(self.t / DEFAULT_BUILD_FOLDER),
                     "--force",
                     "--local",
                     "--version",
@@ -269,7 +342,7 @@ class TestBuildDeployment(BaseCliTest):
             )
             assert (
                 docker_compose["services"][f"abci{i}"]["image"]
-                == f"{OPEN_AEA_IMAGE_NAME}:oracle-{version}"
+                == f"{OPEN_AEA_IMAGE_NAME}:hello_world-{version}"
             )
 
     def test_versioning_kubernetes(
@@ -281,12 +354,9 @@ class TestBuildDeployment(BaseCliTest):
         with mock.patch("os.chown"):
             result = self.run_cli(
                 (
-                    self.service_id,
                     str(self.keys_file),
-                    "--packages-dir",
-                    str(self.t / "packages"),
                     "--o",
-                    str(self.t),
+                    str(self.t / DEFAULT_BUILD_FOLDER),
                     "--force",
                     "--kubernetes",
                     "--local",
@@ -316,7 +386,7 @@ class TestBuildDeployment(BaseCliTest):
 
             assert (
                 resource["spec"]["template"]["spec"]["containers"][1]["image"]
-                == f"{OPEN_AEA_IMAGE_NAME}:oracle-{version}"
+                == f"{OPEN_AEA_IMAGE_NAME}:hello_world-{version}"
             )
 
     def test_docker_compose_no_password(
@@ -327,10 +397,9 @@ class TestBuildDeployment(BaseCliTest):
         with mock.patch("os.chown"):
             result = self.run_cli(
                 (
-                    self.service_id,
                     str(self.keys_file),
                     "--o",
-                    str(self.t),
+                    str(self.t / DEFAULT_BUILD_FOLDER),
                     "--force",
                     "--local",
                 )
@@ -374,10 +443,9 @@ class TestBuildDeployment(BaseCliTest):
         with mock.patch("os.chown"):
             result = self.run_cli(
                 (
-                    self.service_id,
                     str(keys_file),
                     "--o",
-                    str(self.t),
+                    str(self.t / DEFAULT_BUILD_FOLDER),
                     "--force",
                     "--password",
                     ETHEREUM_ENCRYPTION_PASSWORD,
@@ -429,10 +497,9 @@ class TestBuildDeployment(BaseCliTest):
         with mock.patch("os.chown"):
             result = self.run_cli(
                 (
-                    self.service_id,
                     str(keys_file),
                     "--o",
-                    str(self.t),
+                    str(self.t / DEFAULT_BUILD_FOLDER),
                     "--force",
                     "--kubernetes",
                     "--password",
@@ -485,10 +552,9 @@ class TestBuildDeployment(BaseCliTest):
         with mock.patch("os.chown"):
             result = self.run_cli(
                 (
-                    self.service_id,
                     str(self.keys_file),
                     "--o",
-                    str(self.t),
+                    str(self.t / DEFAULT_BUILD_FOLDER),
                     "--force",
                     "--kubernetes",
                     "--local",
