@@ -19,15 +19,18 @@
 
 """Test the `tools/general.py` module of the skill."""
 import json
-from typing import Any, Dict, Optional, Union
+from typing import Dict, Optional, Union
 
 import pytest
 from _pytest.monkeypatch import MonkeyPatch
 
+from autonomy.test_tools.helpers.base import identity
+
 from packages.valory.skills.apy_estimation_abci.tools.queries import (
     block_from_number_q,
     block_from_timestamp_q,
     eth_price_usd_q,
+    existing_pairs_q,
     finalize_q,
     latest_block_q,
     pairs_q,
@@ -77,11 +80,6 @@ eth_q_parameterization = pytest.mark.parametrize(
 )
 
 
-def identity(arg: Any) -> Any:
-    """Define an identity function."""
-    return arg
-
-
 class TestQueries:
     """Tests for `Queries`."""
 
@@ -245,3 +243,22 @@ class TestQueries:
                    }
                    """
         assert actual.split() == expected.split()
+
+    @staticmethod
+    def test_existing_pairs_q(monkeypatch: MonkeyPatch) -> None:
+        """Test `existing_pairs_q`."""
+        monkeypatch.setattr(
+            "packages.valory.skills.apy_estimation_abci.tools.queries.finalize_q",
+            identity,
+        )
+        actual = existing_pairs_q(["x0", "x1", "x2"])
+        expected = """
+                   {
+                       pairs(
+                           where: {id_in: ["x0","x1","x2"]},
+                       ) {
+                           id
+                       }
+                   }
+                   """
+        assert actual.split() == expected.split()
