@@ -62,6 +62,9 @@ from packages.valory.skills.abstract_round_abci.behaviour_utils import (
     RPCResponseStatus,
     make_degenerate_behaviour,
 )
+from packages.valory.skills.abstract_round_abci.test_tools.base import (
+    FSMBehaviourBaseCase,
+)
 from packages.valory.skills.transaction_settlement_abci.behaviours import (
     CheckLateTxHashesBehaviour,
     CheckTransactionHistoryBehaviour,
@@ -91,7 +94,6 @@ from packages.valory.skills.transaction_settlement_abci.rounds import (
 )
 
 from tests.conftest import ROOT_DIR
-from tests.test_skills.base import FSMBehaviourBaseCase
 from tests.test_skills.test_abstract_round_abci.test_common import (
     BaseRandomnessBehaviourTest,
     BaseSelectKeeperBehaviourTest,
@@ -216,14 +218,14 @@ class TestTransactionSettlementBaseBehaviour(PriceEstimationFSMBehaviourBaseCase
             ),
             (
                 MagicMock(performative=ContractApiMessage.Performative.RAW_TRANSACTION),
-                "test_digest",
+                "test_digest_0",
                 RPCResponseStatus.ALREADY_KNOWN,
                 {
                     "blacklisted_keepers": set(),
                     "keeper_retries": 2,
                     "keepers": deque(("agent_1" + "-" * 35, "agent_3" + "-" * 35)),
                     "status": VerificationStatus.PENDING,
-                    "tx_digest": "test_digest",
+                    "tx_digest": "test_digest_0",
                 },
                 False,
             ),
@@ -235,17 +237,18 @@ class TestTransactionSettlementBaseBehaviour(PriceEstimationFSMBehaviourBaseCase
                             "nonce": 0,
                             "maxPriorityFeePerGas": 10,
                             "maxFeePerGas": 20,
+                            "gas": 0,
                         }
                     ),
                 ),
-                "test_digest",
+                "test_digest_1",
                 RPCResponseStatus.SUCCESS,
                 {
                     "blacklisted_keepers": set(),
                     "keeper_retries": 2,
                     "keepers": deque(("agent_1" + "-" * 35, "agent_3" + "-" * 35)),
                     "status": VerificationStatus.PENDING,
-                    "tx_digest": "test_digest",
+                    "tx_digest": "test_digest_1",
                 },
                 False,
             ),
@@ -257,17 +260,18 @@ class TestTransactionSettlementBaseBehaviour(PriceEstimationFSMBehaviourBaseCase
                             "nonce": 0,
                             "maxPriorityFeePerGas": 10,
                             "maxFeePerGas": 20,
+                            "gas": 0,
                         }
                     ),
                 ),
-                "test_digest",
+                "test_digest_2",
                 RPCResponseStatus.SUCCESS,
                 {
                     "blacklisted_keepers": set(),
                     "keeper_retries": 2,
                     "keepers": deque(("agent_1" + "-" * 35, "agent_3" + "-" * 35)),
                     "status": VerificationStatus.PENDING,
-                    "tx_digest": "test_digest",
+                    "tx_digest": "test_digest_2",
                 },
                 True,
             ),
